@@ -18,14 +18,36 @@
 
 # <pep8 compliant>
 import bpy
-from bpy.types import Panel
+from bpy.types import Panel, UIList
 
-from bl_ui.properties_physics_common import (point_cache_ui,
-                                             effector_weights_ui,
-                                             )
+from bl_ui.properties_physics_common import (
+        point_cache_ui,
+        effector_weights_ui,
+        )
 
 
-class PhysicButtonsPanel():
+class PHYSICS_UL_dynapaint_surfaces(UIList):
+    def draw_item(self, context, layout, data, item, icon, active_data, active_propname, index):
+        # assert(isinstance(item, bpy.types.DynamicPaintSurface)
+        surf = item
+        sticon = layout.enum_item_icon(surf, "surface_type", surf.surface_type)
+        if self.layout_type in {'DEFAULT', 'COMPACT'}:
+            row = layout.row(align=True)
+            row.label(text="", icon_value=icon)
+            row.prop(surf, "name", text="", emboss=False, icon_value=sticon)
+            row = layout.row(align=True)
+            if surf.use_color_preview:
+                row.prop(surf, "show_preview", text="", emboss=False,
+                         icon='RESTRICT_VIEW_OFF' if surf.show_preview else 'RESTRICT_VIEW_ON')
+            row.prop(surf, "is_active", text="")
+        elif self.layout_type == 'GRID':
+            layout.alignment = 'CENTER'
+            row = layout.row(align=True)
+            row.label(text="", icon_value=icon)
+            row.label(text="", icon_value=sticon)
+
+
+class PhysicButtonsPanel:
     bl_space_type = 'PROPERTIES'
     bl_region_type = 'WINDOW'
     bl_context = "physics"
@@ -58,14 +80,14 @@ class PHYSICS_PT_dynamic_paint(PhysicButtonsPanel, Panel):
                 surface = canvas.canvas_surfaces.active
 
                 row = layout.row()
-                row.template_list(canvas, "canvas_surfaces", canvas.canvas_surfaces, "active_index", rows=2)
+                row.template_list("PHYSICS_UL_dynapaint_surfaces", "", canvas, "canvas_surfaces",
+                                  canvas.canvas_surfaces, "active_index", rows=1)
 
                 col = row.column(align=True)
                 col.operator("dpaint.surface_slot_add", icon='ZOOMIN', text="")
                 col.operator("dpaint.surface_slot_remove", icon='ZOOMOUT', text="")
 
                 if surface:
-                    layout.prop(surface, "name")
                     layout.prop(surface, "surface_format")
 
                     col = layout.column()
@@ -86,7 +108,7 @@ class PHYSICS_PT_dynamic_paint(PhysicButtonsPanel, Panel):
 
         elif md.ui_type == 'BRUSH':
             brush = md.brush_settings
-            engine = context.scene.render.engine
+            use_shading_nodes = context.scene.render.use_shading_nodes
 
             if brush is None:
                 layout.operator("dpaint.type_toggle", text="Add Brush").type = 'BRUSH'
@@ -101,11 +123,11 @@ class PHYSICS_PT_dynamic_paint(PhysicButtonsPanel, Panel):
                 col.prop(brush, "paint_wetness", text="Wetness")
 
                 col = split.column()
-                if engine == 'BLENDER_RENDER':
+                if not use_shading_nodes:
                     sub = col.column()
                     sub.active = (brush.paint_source != 'PARTICLE_SYSTEM')
                     sub.prop(brush, "use_material")
-                if brush.use_material and brush.paint_source != 'PARTICLE_SYSTEM' and engine == 'BLENDER_RENDER':
+                if brush.use_material and brush.paint_source != 'PARTICLE_SYSTEM' and not use_shading_nodes:
                     col.prop(brush, "material", text="")
                     col.prop(brush, "paint_alpha", text="Alpha Factor")
                 else:
@@ -179,6 +201,7 @@ class PHYSICS_PT_dp_advanced_canvas(PhysicButtonsPanel, Panel):
             col = split.column(align=True)
             col.prop(surface, "wave_damping")
             col.prop(surface, "wave_spring")
+            col.prop(surface, "wave_smoothness")
 
         layout.separator()
         layout.prop(surface, "brush_group")
@@ -214,12 +237,12 @@ class PHYSICS_PT_dp_canvas_output(PhysicButtonsPanel, Panel):
         # vertex format outputs
         if surface.surface_format == 'VERTEX':
             if surface_type == 'PAINT':
-                 # toggle active preview
+                # toggle active preview
                 layout.prop(surface, "preview_id")
 
                 # paint-map output
                 row = layout.row()
-                row.prop_search(surface, "output_name_a", ob.data, "vertex_colors", text="Paintmap layer:")
+                row.prop_search(surface, "output_name_a", ob.data, "vertex_colors", text="Paintmap layer")
                 if surface.output_exists(object=ob, index=0):
                     ic = 'ZOOMOUT'
                 else:
@@ -229,7 +252,7 @@ class PHYSICS_PT_dp_canvas_output(PhysicButtonsPanel, Panel):
 
                 # wet-map output
                 row = layout.row()
-                row.prop_search(surface, "output_name_b", ob.data, "vertex_colors", text="Wetmap layer:")
+                row.prop_search(surface, "output_name_b", ob.data, "vertex_colors", text="Wetmap layer")
                 if surface.output_exists(object=ob, index=1):
                     ic = 'ZOOMOUT'
                 else:
@@ -239,7 +262,7 @@ class PHYSICS_PT_dp_canvas_output(PhysicButtonsPanel, Panel):
 
             elif surface_type == 'WEIGHT':
                 row = layout.row()
-                row.prop_search(surface, "output_name_a", ob, "vertex_groups", text="Vertex Group:")
+                row.prop_search(surface, "output_name_a", ob, "vertex_groups", text="Vertex Group")
                 if surface.output_exists(object=ob, index=0):
                     ic = 'ZOOMOUT'
                 else:
@@ -250,7 +273,7 @@ class PHYSICS_PT_dp_canvas_output(PhysicButtonsPanel, Panel):
         # image format outputs
         if surface.surface_format == 'IMAGE':
             layout.operator("dpaint.bake", text="Bake Image Sequence", icon='MOD_DYNAMICPAINT')
-            layout.prop_search(surface, "uv_layer", ob.data, "uv_textures", text="UV Map:")
+            layout.prop_search(surface, "uv_layer", ob.data, "uv_textures", text="UV Map")
             layout.separator()
 
             layout.prop(surface, "image_output_path", text="")
@@ -301,7 +324,8 @@ class PHYSICS_PT_dp_canvas_initial_color(PhysicButtonsPanel, Panel):
         ob = context.object
 
         layout.prop(surface, "init_color_type", expand=False)
-        layout.separator()
+        if surface.init_color_type != 'NONE':
+            layout.separator()
 
         # dissolve
         if surface.init_color_type == 'COLOR':
@@ -309,10 +333,10 @@ class PHYSICS_PT_dp_canvas_initial_color(PhysicButtonsPanel, Panel):
 
         elif surface.init_color_type == 'TEXTURE':
             layout.prop(surface, "init_texture")
-            layout.prop_search(surface, "init_layername", ob.data, "uv_textures", text="UV Map:")
+            layout.prop_search(surface, "init_layername", ob.data, "uv_textures", text="UV Map")
 
         elif surface.init_color_type == 'VERTEX_COLOR':
-            layout.prop_search(surface, "init_layername", ob.data, "vertex_colors", text="Color Layer:")
+            layout.prop_search(surface, "init_layername", ob.data, "vertex_colors", text="Color Layer")
 
 
 class PHYSICS_PT_dp_effects(PhysicButtonsPanel, Panel):
@@ -349,7 +373,7 @@ class PHYSICS_PT_dp_effects(PhysicButtonsPanel, Panel):
 
             col = layout.column()
             col.active = surface.use_drip
-            effector_weights_ui(self, context, surface.effector_weights)
+            effector_weights_ui(self, context, surface.effector_weights, 'DYNAMIC_PAINT')
 
             layout.label(text="Surface Movement:")
             row = layout.row()
